@@ -1,4 +1,4 @@
-# $Id: Depend.pm,v 1.14 2005/12/26 13:57:46 joern Exp $
+# $Id: Depend.pm,v 1.16 2006/03/27 21:29:07 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -20,7 +20,7 @@ use Carp;
 use strict;
 
 my @DVDRIP_BIN_FILES = qw (
-    dvdrip              dvdrip-exec
+    dvdrip              execflow
     dvdrip-master       dvdrip-multitee
     dvdrip-progress     dvdrip-tet
     dvdrip-splitpipe    dvdrip-subpng
@@ -70,7 +70,6 @@ my %TOOLS = (
         optional    => 0,
         get_version => sub {
             qx[transcode -v 2>&1] =~ /v(\d+\.\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert       => 'default',
@@ -89,7 +88,6 @@ my %TOOLS = (
         optional    => 0,
         get_version => sub {
             qx[convert -version 2>&1] =~ /ImageMagick\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -103,7 +101,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[xvid4conf -v 2>&1] =~ /(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -117,7 +114,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[subtitle2pgm -h  2>&1] =~ /version\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -131,7 +127,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[lsdvd -V  2>&1] =~ /lsdvd\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -147,7 +142,6 @@ my %TOOLS = (
             my $self = shift;
             my $rar  = $self->config('rar_command');
             qx[$rar '-?' 2>&1] =~ /rar\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -162,7 +156,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             my $out = qx[mplayer --help 2>&1];
-            wait;    # saw zombies on a Slackware system without it.
             if ( $out =~ /CVS/i ) {
                 return "cvs";
             }
@@ -182,7 +175,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[ogmmerge -V 2>&1] =~ /v(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -196,7 +188,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[dvdxchap -V 2>&1] =~ /v(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -210,7 +201,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[mplex --help 2>&1] =~ /version\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -225,7 +215,6 @@ my %TOOLS = (
         get_version => sub {
             qx[cdrdao show-toc -h 2>&1]
                 =~ /version\s+(\d+\.\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -239,7 +228,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[vcdimager -V 2>&1] =~ /vcdimager.*?\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -253,7 +241,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[mkisofs -version 2>&1] =~ /mkisofs\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -267,7 +254,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[cdrecord -version 2>&1] =~ /(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -281,7 +267,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[dvdrecord -version 2>&1] =~ /(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -295,7 +280,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[xine -version 2>&1] =~ /v(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
@@ -309,7 +293,6 @@ my %TOOLS = (
         optional    => 1,
         get_version => sub {
             qx[/usr/sbin/fping -v 2>&1] =~ /Version\s+(\d+\.\d+(\.\d+)?)/i;
-            wait;    # saw zombies on a Slackware system without it.
             return $1;
         },
         convert   => 'default',
