@@ -1,4 +1,4 @@
-# $Id: BitrateCalc.pm,v 1.9 2005/12/26 13:57:47 joern Exp $
+# $Id: BitrateCalc.pm,v 1.11 2006/04/10 19:46:00 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -98,7 +98,6 @@ sub build_calc_list {
 	);
 
 	return Gtk2::Ex::FormFactory::VBox->new (
-	    title  => __"Storage and bitrate calculation details",
 	    expand => 1,
 	    content => [
 		Gtk2::Ex::FormFactory::List->new (
@@ -117,29 +116,4 @@ sub build_calc_list {
 	);
 }
 
-sub build_depend_notes {
-	my $self = shift;
-	
-	return Gtk2::Ex::FormFactory::Label->new (
-	    label => __("- Mandatory tools must be present with the minimum version listed.\n".
-	    		"- Non mandatory tools may be missing or too old - features are disabled then.\n".
-			"- Suggested numbers are the versions the author works with, so they are well tested.")
-
-	);
-}
-
-sub show_text_version {
-	my $self = shift;
-	
-	my $message = $self->depend_object->installed_tools_as_text;
-	
-	$self->long_message_window (
-	    title   => __"Installed tools",
-	    message => $message,
-	    fixed   => 1,
-	);
-	
-	1;
-}
-
 1;
