@@ -1,4 +1,4 @@
-# $Id: Context.pm,v 1.7 2006/01/03 19:35:12 joern Exp $
+# $Id: Context.pm,v 1.11 2006/04/10 19:48:03 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -31,8 +31,10 @@ my @BITRATE_PARAMS = (
     "title.tc_clip2_right",                 "title.tc_start_frame",
     "title.tc_end_frame",                   "audio_track.tc_audio_codec",
     "audio_track.tc_mp3_bitrate",           "audio_track.tc_mp2_bitrate",
+    "audio_track.tc_ac3_bitrate",           "audio_track.tc_pcm_bitrate",
     "audio_track.tc_vorbis_bitrate",        "audio_track.tc_vorbis_quality",
     "audio_track.tc_vorbis_quality_enable", "multi_audio.matrix",
+    "audio_track.bitrate",
 );
 
 sub create {
@@ -192,6 +194,8 @@ sub create {
         name   => "project",
         object => undef,
 
+        changes_attr_filter => qr[^last_selected_nb_page$],
+
         attr_depends_href => {
             vob_dir       => "project.name",
             avi_dir       => "project.name",
@@ -284,7 +288,7 @@ sub create {
                 my @audio_list;
                 my $i = 0;
                 foreach my $audio ( @{$audio_tracks} ) {
-                    push @audio_list, "$i: "
+                    push @audio_list, ($i+1).": "
                         . $audio->info( with_target => $with_target_track );
                     ++$i;
                 }
@@ -416,6 +420,9 @@ sub create {
             tc_keyframe_interval_presets => [ 25, 50, 100, 150, 250 ],
 
             #-- Video framerate presets
+            tc_video_af6_codec_presets => [ "mpeg4", "h264" ],
+
+            #-- ffmpeg video codec presets
             tc_video_framerate_presets => [ 25, 23.976, 29.97 ],
 
             #-- List of deinterlacers
@@ -553,10 +560,13 @@ sub create {
             preview_filename_clip2 => sub { -f $_[0]->preview_filename_zoom },
 
             #-- multipass only with non MPEG files
-            tc_multipass => sub { ! $_[0]->is_mpeg },
+            tc_multipass => sub { ! $_[0]->is_mpeg &&
+                                    $_[0]->tc_video_af6_codec ne 'h264' },
 
             #-- reuse log active only with 2pass encoding
-            tc_multipass_reuse_log => sub { $_[0]->tc_multipass && ! $_[0]->is_mpeg },
+            tc_multipass_reuse_log => sub { $_[0]->tc_multipass &&
+                                            ! $_[0]->is_mpeg  &&
+                                              $_[0]->tc_video_af6_codec ne 'h264' },
 
             #-- fast resizing
             tc_fast_resize => sub { $_[0]->fast_resize_possible },
@@ -617,10 +627,10 @@ sub create {
             tc_video_bitrate_manual => "tc_video_codec",
 
             #-- multipass depends on container
-            tc_multipass => "tc_container",
+            tc_multipass => [ "tc_container", "tc_video_af6_codec" ],
             
             #-- reuse log active only with 2pass encoding
-            tc_multipass_reuse_log => [ "tc_container", "tc_multipass" ],
+            tc_multipass_reuse_log => [ "tc_container", "tc_multipass", "tc_video_af6_codec" ],
 
             #-- fast resizing depends on a bunch of parameters
             tc_fast_resize => [
@@ -700,7 +710,6 @@ sub create {
             },
             audio_codec_ac3_form => sub {
                 $context->get_object("title")->tc_container ne 'vcd'
-                    && shift->ac3_ok;
             },
             audio_codec_pcm_form => sub {
                 $context->get_object("title")->tc_container ne 'vcd'
@@ -814,6 +823,12 @@ sub create {
         object => undef,
     );
 
+    #-- Add cluster control daemon object to Context
+    $context->add_object(
+        name   => "!cluster",
+        object => 1,
+    );
+
     #-- Add cluster control GUI object to Context
     $context->add_object(
         name              => "cluster_gui",
@@ -868,6 +883,12 @@ sub create {
         buffered => 1,
     );
 
+    #-- Add currently cluster title GUI object to Context
+    $context->add_object(
+        name     => "cluster_title_gui",
+#        buffered => 1,
+    );
+
     #-- Add currently edited cluster title object to Context
     $context->add_object( name => "cluster_title_edited", );
 
