@@ -1,4 +1,4 @@
-# $Id: Transcode.pm,v 1.7 2005/12/26 13:57:47 joern Exp $
+# $Id: Transcode.pm,v 1.15 2006/04/10 19:50:53 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -34,7 +34,7 @@ sub build_factory {
     my $context = $self->get_context;
 
     return Gtk2::Ex::FormFactory::VBox->new(
-        title       => __ "Transcode",
+        title       => '[gtk-convert]'.__ "Transcode",
         object      => "title",
         active_cond => sub {
             $self->project
@@ -122,7 +122,7 @@ sub build_video_factory {
             ),
             Gtk2::Ex::FormFactory::Combo->new(
                 attr  => "title.tc_video_codec",
-                width => 70,
+                width => 80,
                 tip   => __ "Choose a video codec here. If you don't "
                     . "find the codec you want in the list, just "
                     . "enter its transcode name by hand",
@@ -147,9 +147,9 @@ sub build_video_factory {
                 label => __ "ffmpeg/af6 codec",
                 for   => "sibling(1)"
             ),
-            Gtk2::Ex::FormFactory::Entry->new(
+            Gtk2::Ex::FormFactory::Combo->new(
                 attr  => "title.tc_video_af6_codec",
-                width => 70,
+                width => 80,
                 tip   => __ "Some transcode video export modules support "
                     . "multiple video codecs, e.g. the ffmpeg module. "
                     . "Enter the name of the video codec the module "
@@ -173,7 +173,7 @@ sub build_video_factory {
             ),
             Gtk2::Ex::FormFactory::Combo->new(
                 attr  => "title.tc_video_framerate",
-                width => 70,
+                width => 80,
                 tip   => __ "This is the video framerate of this movie. "
                     . "Only change this if transcode detected the "
                     . "framerate wrong, which may happen sometimes. "
@@ -268,6 +268,14 @@ sub build_audio_factory {
             ),
             Gtk2::Ex::FormFactory::Notebook->new(
                 attr    => "audio_track.tc_audio_codec",
+                changed_hook_after => sub {
+                    my $audio_track = $self->get_context->get_object("audio_track");
+                    return if ! $audio_track;
+                    if ( $audio_track->tc_audio_codec =~ /^(?:ac3|pcm)$/ ) {
+                        $self->detect_audio_bitrate
+                            unless $audio_track->bitrate;
+                    }
+                },
                 content => [
                     $self->build_audio_codec_settings( type => "mp3" ),
                     $self->build_audio_codec_settings( type => "mp2" ),
@@ -291,6 +299,7 @@ sub build_audio_codec_settings {
     my $samplerate_entry_class = "Gtk2::Ex::FormFactory::Combo";
     my $bitrate_attr           = "tc_${type}_bitrate";
     my $samplerate_attr        = "tc_${type}_samplerate";
+    my $changed_hook;
 
     if ( $type eq 'mp3' ) {
         $title = "MP3";
@@ -329,15 +338,16 @@ sub build_audio_codec_settings {
     }
     else {
         my $codec = $type eq 'ac3' ? "AC3" : "PCM";
+        my $bitrate_attr_method = $bitrate_attr;
         $title = $codec;
         push @additional_widgets,
             Gtk2::Ex::FormFactory::Label->new(
-            label => __x(
-                "{ac3_or_pcm} sound is passed through. Bit- and\n"
-                    . "samplerate are detected from source,\n"
-                    . "so you can't change them here.",
-                ac3_or_pcm => $codec
-            ),
+                label => __x(
+                    "{ac3_or_pcm} sound is passed through. Bit- and\n"
+                        . "samplerate are detected from source,\n"
+                        . "so you can't change them here.",
+                    ac3_or_pcm => $codec
+                ),
             );
         $bitrate_entry_class    = "Gtk2::Ex::FormFactory::Entry";
         $samplerate_entry_class = "Gtk2::Ex::FormFactory::Entry";
@@ -365,6 +375,8 @@ sub build_audio_codec_settings {
                         clicked_hook => sub {
                             $self->scan_rescale_volume;
                         },
+                        active_cond    => sub { !$self->progress_is_active },
+                        active_depends => "progress.is_active",
                     ),
                 ],
             ),
@@ -373,10 +385,10 @@ sub build_audio_codec_settings {
     }
 
     return Gtk2::Ex::FormFactory::Form->new(
-        attr     => "audio_track.audio_codec_${type}_form",
-        inactive => "invisible",
-        title    => $title,
-        content  => [
+        attr         => "audio_track.audio_codec_${type}_form",
+        inactive     => "invisible",
+        title        => $title,
+        content      => [
             Gtk2::Ex::FormFactory::HBox->new(
                 label   => __ "Bit-/Samplerate",
                 content => [
@@ -635,8 +647,10 @@ sub build_operate_factory {
                         widget_group => "operate_buttons",
                         expand       => 1,
                         clicked_hook => sub {
-                            $self->transcode,;
+                            $self->transcode;
                         },
+                        active_cond    => sub { !$self->progress_is_active },
+                        active_depends => "progress.is_active",
                     ),
                     Gtk2::Ex::FormFactory::Button->new(
                         label        => __ "View",
@@ -646,6 +660,8 @@ sub build_operate_factory {
                         clicked_hook => sub {
                             $self->view_avi,;
                         },
+                        active_cond    => sub { !$self->progress_is_active },
+                        active_depends => "progress.is_active",
                     ),
                     Gtk2::Ex::FormFactory::Button->new(
                         label        => __ "Add to cluster",
@@ -655,6 +671,12 @@ sub build_operate_factory {
                         clicked_hook => sub {
                             $self->add_to_cluster;
                         },
+                        active_cond    => sub {
+                            my $title = $self->selected_title;
+                            return 0 if not $title;
+                            return $title->tc_container ne 'vcd';
+                        },
+                        active_depends => "title.tc_container",
                     ),
                 ],
             ),
@@ -722,7 +744,7 @@ _ Details                   |   | Total Size     |     Value | MB  |
             #-- 4th row
             Gtk2::Ex::FormFactory::Button->new(
                 label        => __ "Details...",
-                stock        => "gtk-justify-left",
+                stock        => "gtk-zoom-in",
                 clicked_hook => sub {
                     $self->open_bitrate_calc_details;
                 },
@@ -793,34 +815,14 @@ sub transcode {
     my ($subtitle_test) = @par{'subtitle_test'};
 
     return 1 if $self->progress_is_active;
-
     my $title = $self->selected_title;
-
     return 1 if not $title;
 
-    Video::DVDRip::InfoFile->new(
-        title    => $title,
-        filename => $title->info_file,
-    )->write;
+    my $job_planner   = $self->get_context->get_object("job_planner");
+    my $exec_flow_gui = $self->get_context->get_object("exec_flow_gui");
+    my $job           = $job_planner->build_transcode_job();
 
-    require Video::DVDRip::Task::Transcode;
-
-    my $task = Video::DVDRip::Task::Transcode->new(
-        ui                      => $self,
-        project                 => $self->project,
-        cb_update_video_bitrate => sub {
-            $self->get_context->update_object_attr_widgets(
-                "title.tc_video_bitrate");
-        },
-        cb_exit_proram => sub {
-            $self->get_context_object("main")
-                ->exit_program(
-                force => ( $title->tc_exit_afterwards eq 'dont_save' ) );
-        },
-    );
-
-    $task->configure;
-    $task->start;
+    $exec_flow_gui->start_job($job);
 
     1;
 }
@@ -841,7 +843,6 @@ sub view_avi {
 
 sub scan_rescale_volume {
     my $self = shift;
-    $self->trace_in;
 
     my $title = $self->selected_title;
     return 1 if $self->progress_is_active;
@@ -853,37 +854,17 @@ sub scan_rescale_volume {
         return 1;
     }
 
-    my $job;
-    my $nr;
-    my $chapter_count = 0;
-    my $last_job;
-    my $exec = $self->new_job_executor;
+    my $job_planner   = $self->get_context->get_object("job_planner");
+    my $exec_flow_gui = $self->get_context->get_object("exec_flow_gui");
+    my $job           = $job_planner->build_scan_volume_job($title);
 
-    my $chapters = $title->get_chapters;
+    $job->get_post_callbacks->add(sub {
+        $self->get_context->update_object_attr_widgets(
+            "audio_track.tc_volume_rescale", );
+        1;
+    });
 
-    if ( not $title->tc_use_chapter_mode ) {
-        $chapters = [undef];
-    }
-
-    foreach my $chapter ( @{$chapters} ) {
-        $job = Video::DVDRip::Job::ScanVolume->new(
-            nr    => ++$nr,
-            title => $title,
-        );
-        $job->set_chapter($chapter);
-        $job->set_count( $chapter_count++ );
-        $last_job = $exec->add_job( job => $job );
-    }
-
-    $exec->set_cb_finished(
-        sub {
-            $self->get_context->update_object_attr_widgets(
-                "audio_track.tc_volume_rescale", );
-            1;
-        }
-    );
-
-    $exec->execute_jobs;
+    $exec_flow_gui->start_job($job);
 
     1;
 }
@@ -918,12 +899,6 @@ sub add_to_cluster {
         return 1;
     }
 
-    if ( $title->get_first_audio_track < 0 ) {
-        $self->message_window(
-            message => __ "You have no target audio track selected." );
-        return 1;
-    }
-
     if ( $title->tc_container eq 'vcd' ) {
         $self->message_window( message => __
                 "MPEG processing is not supported for cluster mode." );
@@ -946,6 +921,7 @@ sub add_to_cluster {
 
     my $cluster_gui = eval { $self->get_context_object('cluster_gui') };
     return if not $cluster_gui;
+    return if not $cluster_gui->master;
 
     $cluster_gui->add_project(
         project => $self->project,
@@ -961,27 +937,27 @@ sub create_wav {
     my $title = $self->selected_title;
     return 1 if not $title;
 
-    my $nr;
-    my $last_job;
-    my $exec = $self->new_job_executor;
+    my $job_planner   = $self->get_context->get_object("job_planner");
+    my $exec_flow_gui = $self->get_context->get_object("exec_flow_gui");
+    my $job           = $job_planner->build_create_wav_job($title);
 
-    my $chapters = $title->get_chapters;
+    $exec_flow_gui->start_job($job);
 
-    if ( not $title->tc_use_chapter_mode ) {
-        $chapters = [undef];
-    }
+    1;
+}
 
-    my $job;
-    foreach my $chapter ( @{$chapters} ) {
-        $job = Video::DVDRip::Job::CreateWav->new(
-            nr    => ++$nr,
-            title => $title,
-        );
-        $job->set_chapter($chapter);
-        $last_job = $exec->add_job( job => $job );
-    }
+sub detect_audio_bitrate {
+    my $self = shift;
+    my ($codec_attr) = @_;
 
-    $exec->execute_jobs;
+    my $title = $self->selected_title;
+    return 1 if not $title;
+
+    my $job_planner   = $self->get_context->get_object("job_planner");
+    my $exec_flow_gui = $self->get_context->get_object("exec_flow_gui");
+    my $job           = $job_planner->build_detect_audio_bitrate_job($title, $codec_attr);
+
+    $exec_flow_gui->start_job($job);
 
     1;
 }
