@@ -1,4 +1,4 @@
-# $Id: JobPlanner.pm,v 1.6 2006/04/10 19:51:05 joern Exp $
+# $Id: JobPlanner.pm,v 1.7 2006/04/23 14:25:14 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -1553,7 +1553,7 @@ sub build_scan_volume_job {
             $progress_max = $title->get_vob_size;
 
         }
-        elsif ( not $self->chapter ) {
+        elsif ( not $chapter ) {
             $progress_ips = __"fps";
             $progress_max = $title->frames;
         }
