@@ -1,9 +1,9 @@
-# $Id: PSU.pm,v 1.5 2005/12/26 13:57:46 joern Exp $
+# $Id: PSU.pm,v 1.6 2006/03/29 20:23:37 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
-# 
+#
 # This program is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
@@ -24,17 +24,16 @@ sub set_nr			{ shift->{nr}			= $_[1] }
 sub set_frames			{ shift->{frames}		= $_[1]	}
 
 sub new {
-	my $class = shift;
-	my %par = @_;
-	my  ($nr, $frames) =
-	@par{'nr','frames'};
+    my $class = shift;
+    my %par   = @_;
+    my ( $nr, $frames ) = @par{ 'nr', 'frames' };
 
-	my $self = bless {
-		nr	 => $nr,
-		frames	 => $frames,
-	}, $class;
-	
-	return $self;
+    my $self = bless {
+        nr     => $nr,
+        frames => $frames,
+    }, $class;
+
+    return $self;
 }
 
 1;
