@@ -1,9 +1,9 @@
-# $Id: SrtxFile.pm,v 1.2 2005/12/26 13:57:46 joern Exp $
+# $Id: SrtxFile.pm,v 1.3 2006/03/29 20:23:37 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
-# 
+#
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
@@ -26,57 +26,58 @@ sub set_filename                { shift->{filename}             = $_[1] }
 sub set_fh                      { shift->{fh}                   = $_[1] }
 
 sub new {
-    my $class = shift;
-    my %par = @_;
+    my $class      = shift;
+    my %par        = @_;
     my ($filename) = @par{'filename'};
 
     my $self = bless {
-        filename        => $filename,
-        fh              => FileHandle->new,
+        filename => $filename,
+        fh       => FileHandle->new,
     }, $class;
 
     return $self;
 }
 
 sub set_filename_from_dir {
-    my $self = shift;
-    my ($dir) = @_;
-    my $filename  = (glob("$dir/{*.srtx,.*srtx}"))[0];
+    my $self     = shift;
+    my ($dir)    = @_;
+    my $filename = ( glob("$dir/{*.srtx,.*srtx}") )[0];
     return $self->set_filename($filename);
 }
 
 sub open {
     my $self = shift;
-    
+
     my $fh       = $self->get_fh;
     my $filename = $self->get_filename;
-    
-    open ($fh, $filename) or die "can't read $filename";
 
-    1;    
+    open( $fh, $filename ) or die "can't read $filename";
+
+    1;
 }
 
 sub close {
     my $self = shift;
-    
-    close ($self->get_fh);
-    
+
+    close( $self->get_fh );
+
     1;
 }
 
 sub read_entry {
     my $self = shift;
-    
+
     my $fh = $self->get_fh;
-    
-    chomp(my $nr         = <$fh>);
-    chomp(my $time       = <$fh>);
-    chomp(my $image_file = <$fh>);
+
+    chomp( my $nr         = <$fh> );
+    chomp( my $time       = <$fh> );
+    chomp( my $image_file = <$fh> );
     <$fh>;
 
-    return unless defined $nr
-              and defined $time
-              and defined $image_file;
+    return
+        unless defined $nr
+        and defined $time
+        and defined $image_file;
 
     $image_file =~ s/\.pgm\.txt$//;
 
@@ -90,10 +91,10 @@ sub read_entry {
         $image_file = undef;
     }
 
-    return Video::DVDRip::SrtxFileEntry->new (
-        nr          => $nr,
-        time        => $time,
-        image_file  => $image_file,
+    return Video::DVDRip::SrtxFileEntry->new(
+        nr         => $nr,
+        time       => $time,
+        image_file => $image_file,
     );
 }
 
@@ -111,9 +112,8 @@ sub set_image_file              { shift->{image_file}           = $_[1] }
 
 sub new {
     my $class = shift;
-    my %par = @_;
-    my  ($nr, $time, $image_file) =
-    @par{'nr','time','image_file'};
+    my %par   = @_;
+    my ( $nr, $time, $image_file ) = @par{ 'nr', 'time', 'image_file' };
 
     ($time) = $time =~ /^(\d\d:\d\d:\d\d)/;
     $time =~ /^(\d\d):(\d\d):(\d\d)/;
@@ -121,12 +121,12 @@ sub new {
     my $time_sec = $3 + $2 * 60 + $1 * 3600;
 
     my $self = bless {
-        nr          => $nr,
-        time        => $time,
-        time_sec    => $time_sec,
-        image_file  => $image_file,
+        nr         => $nr,
+        time       => $time,
+        time_sec   => $time_sec,
+        image_file => $image_file,
     }, $class;
-    
+
     return $self;
 }
 
